@@ -16,10 +16,24 @@ get_match_details <- function(match_id) {
 
   url <- paste(prefix, match_id, sep = "")
 
-  readlines <- readLines(url, warn = FALSE)
+  out <- tryCatch({
+    fromJSON(url)
+  },
+  error = function(cond) {
+    message(paste("URL does not seem to exist:", url))
+    message("Here's the original error message:")
+    message(cond)
+    # Choose a return value in case of error
+    return(NA)
+  },
+  warning = function(cond) {
+    message(paste("URL caused a warning:", url))
+    message("Here's the original warning message:")
+    message(cond)
+    # Choose a return value in case of warning
+    return(NULL)
+  })
 
-  matchDetails <- fromJSON(readlines)
-
-  return(matchDetails)
+  return(out)
 
 }
